# `pylsf`

A Python tool for analyzing LSF (bsub) cluster GPU usage.

```bash
pylsf_avail  # check GPU and node usage on the cluster
```

## Installation

```bash
pip install pylsf
```

**Development**

```bash
uv sync --dev 
uv pip install -e .
```
